@@ -94,6 +94,14 @@ from gopup.economic.shibor import (
     lpr_data
 )
 
+"""
+中国油价数据
+"""
+from gopup.life.oil import (
+    energy_oil_hist,
+    energy_oil_detail
+)
+
 """
 新经济公司
 """
